pub struct RegisteredWebhook {
pub created_webhook_id: Option<i64>,
pub errors: Option<Vec<String>>,
}Expand description
RegisteredWebhook : ID of a registered webhook or error messages explaining why a webhook wasn’t registered.
Fields
created_webhook_id: Option<i64>The ID of the webhook. Returned if the webhook is created.
errors: Option<Vec<String>>Error messages specifying why the webhook creation failed.
Implementations
Sourceimpl RegisteredWebhook
impl RegisteredWebhook
Sourcepub fn new() -> RegisteredWebhook
pub fn new() -> RegisteredWebhook
ID of a registered webhook or error messages explaining why a webhook wasn’t registered.